@@ -1,7 +1,7 @@
 package Aniki::Plugin::Count;
 use 5.014002;
 
-use namespace::autoclean;
+use namespace::sweep;
 use Mouse::Role;
 
 use Carp qw/croak/;
